@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2012 The QXmpp developers
+ * Copyright (C) 2008-2014 The QXmpp developers
  *
  * Author:
  *	Manjeet Dahiya
@@ -22,7 +22,7 @@
  */
 
 
-#include <QtGui/QApplication>
+#include <QApplication>
 #include <QDir>
 
 #include "mainDialog.h"
