@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2012 The QXmpp developers
+ * Copyright (C) 2008-2014 The QXmpp developers
  *
  * Author:
  *	Manjeet Dahiya
@@ -24,7 +24,11 @@
 
 #include "utils.h"
 #include <QDir>
+#if QT_VERSION >= 0x050000
+#include <QStandardPaths>
+#else
 #include <QDesktopServices>
+#endif
 
 int comparisonWeightsPresenceStatusType(QXmppPresence::AvailableStatusType statusType)
 {
@@ -99,7 +103,12 @@ QString presenceToStatusText(const QXmppPresence& presence)
 
 QString getSettingsDir(const QString& bareJid)
 {
+#if QT_VERSION >= 0x050000
+    QStringList dirList = QStandardPaths::standardLocations(QStandardPaths::DataLocation);
+    QString dir = dirList.size() > 0 ? dirList.at(0) : "";
+#else
     QString dir = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
+#endif
     if(bareJid.isEmpty())
         return dir + "/";
     else
