@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2012 The QXmpp developers
+ * Copyright (C) 2008-2014 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -25,6 +25,7 @@
 #include "QXmppUtils.h"
 
 #include <QDomElement>
+#include <QTextStream>
 
 class QXmppElementPrivate
 {
@@ -40,6 +41,8 @@ public:
     QList<QXmppElementPrivate*> children;
     QString name;
     QString value;
+
+    QByteArray serializedSource;
 };
 
 QXmppElementPrivate::QXmppElementPrivate()
@@ -78,6 +81,9 @@ QXmppElementPrivate::QXmppElementPrivate(const QDomElement &element)
         }
         childNode = childNode.nextSibling();
     }
+
+    QTextStream stream(&serializedSource);
+    element.save(stream, 0);
 }
 
 QXmppElementPrivate::~QXmppElementPrivate()
@@ -124,6 +130,21 @@ QXmppElement &QXmppElement::operator=(const QXmppElement &other)
     return *this;
 }
 
+QDomElement QXmppElement::sourceDomElement() const
+{
+    if (d->serializedSource.isEmpty())
+        return QDomElement();
+
+    QDomDocument doc;
+    if (!doc.setContent(d->serializedSource, true))
+    {
+        qWarning("[QXmpp] QXmppElement::sourceDomElement(): cannot parse source element");
+        return QDomElement();
+    }
+
+    return doc.documentElement();
+}
+
 QStringList QXmppElement::attributeNames() const
 {
     return d->attributes.keys();
