@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2012 The QXmpp developers
+ * Copyright (C) 2008-2014 The QXmpp developers
  *
  * Authors:
  *  Manjeet Dahiya
@@ -103,8 +103,11 @@ private:
 QXmppOutgoingClientPrivate::QXmppOutgoingClientPrivate(QXmppOutgoingClient *qq)
     : redirectPort(0)
     , sessionAvailable(false)
+    , sessionStarted(false)
     , isAuthenticated(false)
     , saslClient(0)
+    , pingTimer(0)
+    , timeoutTimer(0)
     , q(qq)
 {
 }
