@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2012 The QXmpp developers
+ * Copyright (C) 2008-2014 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -712,7 +712,7 @@ void QXmppTransferOutgoingJob::_q_sendData()
         terminate(QXmppTransferJob::FileAccessError);
         return;
     }
-    if (length > 0)
+    if (length >= 0)
     {
         d->socksSocket->write(buffer, length);
         delete [] buffer;
